# Generated by Django 3.2.13 on 2022-04-17 14:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('simpel_partners', '0002_auto_20220417_1416'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='partneraddress',
            name='address_type',
        ),
        migrations.RemoveField(
            model_name='partneraddress',
            name='primary',
        ),
        migrations.AlterField(
            model_name='partneraddress',
            name='title',
            field=models.CharField(blank=True, choices=[('Mr', 'Mr'), ('Miss', 'Miss'), ('Mrs', 'Mrs'), ('Ms', 'Ms'), ('Dr', 'Dr')], help_text='Treatment Pronouns for the customer', max_length=64, verbose_name='Title'),
        ),
    ]
