# Generated by Django 3.2.12 on 2022-04-17 14:16

from django.db import migrations, models
import simpel_utils.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('simpel_partners', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='partner',
            name='idn',
            field=models.CharField(help_text='Identification Number', max_length=25, null=True, verbose_name='Identification Number'),
        ),
        migrations.AlterField(
            model_name='partner',
            name='tax_id',
            field=models.CharField(blank=True, help_text='Tax ID', max_length=25, null=True, verbose_name='Tax ID'),
        ),
        migrations.AlterField(
            model_name='partneraddress',
            name='line_2',
            field=simpel_utils.models.fields.NullCharField(max_length=255, verbose_name='line 2'),
        ),
        migrations.AlterField(
            model_name='partneraddress',
            name='line_3',
            field=simpel_utils.models.fields.NullCharField(max_length=255, verbose_name='line 3'),
        ),
    ]
