# Generated by Django 3.2.13 on 2022-04-20 16:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('simpel_partners', '0003_auto_20220417_1439'),
    ]

    operations = [
        migrations.AddField(
            model_name='partneraddress',
            name='address_type',
            field=models.CharField(choices=[('home', 'Home'), ('office', 'Office'), ('branch_office', 'Branch Office'), ('billing', 'Billing'), ('shipping', 'Shipping'), ('drop_shipping', 'Dropshipping'), ('deliverable', 'Deliverable'), ('else', 'Else')], default='billing', help_text='E.g. Shipping or billing', max_length=255, verbose_name='type'),
        ),
        migrations.AddField(
            model_name='partneraddress',
            name='primary',
            field=models.BooleanField(default=False),
        ),
    ]
